#!/bin/sh

#
#
# Quick and dirty script to start cave-mplayer on LAN
#
# You MUST edit:
#
#	HOSTS	variable (list of hosts which will run cmplayer)
#	BCAST	broadcast address of $HOSTS
#	MASTER  the IP of master server (attached to same network as $HOSTS)
#	BASE	base path of cmplayer installation
#           $BASE/bin/cave-mplayer is your patched mplayer binary
#           $BASE/bin/cmplayerc must exist
#           $BASE/bin/cmplayers must exist
#	BM		base path of movies
#	RSH		rsh/ssh command to use
#
# Requires:
#	killall (linux syntax)
#	rsh/ssh setup to allow remote commands w/o auth dialog
#

HOSTS="n-n01 n-n02 n-n03 n-n04 n-n05 n-n06"
N=`echo "$HOSTS" | wc -w | tr -d ' '`

BCAST=192.168.1.255

MASTER=`hostname`
BASE=/scratch/cave-mplayer
RSH="ssh -x -n"
#RSH="rsh -n"

BM=/scratch/movies


PG=cave-mplayer
UDP=-udp
#UDP=""
TCP="-srv $MASTER"
#TCP=""

if [ "_$2" = "_" ]
then
	echo Use: $0 "[start|stop] movie"
	exit 1
fi

MOVIE=$BM/$2

PATH=$PATH:/usr/local/bin:$BASE/bin
export PATH


case $1 in
	"start")
		
		echo "####"
		echo "#"
		echo "# Starting cmplayers to receive \"READY\" signals"
		echo "#"

		cmplayers -d -p 7687 -n $N -t 5 &

		echo "#"
		echo "# Starting cave-mplayer on every host"
		echo "#"

		for h in $HOSTS
		do
			$RSH $h \
			env \
			DISPLAY=:0.0 \
			$BASE/bin/cave-mplayer \
				$UDP $TCP \
				-framedrop \
				-autosync 0 \
				-quiet \
				-nosound \
				-fs \
			$MOVIE \> $h.log 2\>\&1 &
			echo $h
		done
		echo "#"
		echo "# waiting for $N answers"
		echo "#"
		if wait %1
		then
			echo starting players
			set -x
			cmplayerc \
				-H $BCAST -p 7686 -b -a $N -t 5
			echo "#"
			echo "# All clients started"
			echo "#"
		else
			echo "#### ERROR: Some clients failed to start"
			./cmplayer.sh stop $MOVIE
		fi
		;;

	"stop")

		for h in $HOSTS
		do
			$RSH $h \
			killall -s TERM $PG
			echo $h
		done
		sleep 2
		;;

esac

